package labeling;

/**
 * @author haunert
 * 
 * When using or adapting this code for your research, please cite:
 * 
 * Jan-Henrik Haunert and Alexander Wolff
 * Beyond Maximum Independent Set: An Extended Integer Programming Formulation for Point Labeling
 * International Journal of Geo-Information, 2017
 */
public class Interference implements Comparable<Interference> {
	private Label l1;
	private Label l2;
	
	public Interference(Label label1, Label label2) {
		if (label1.getIndex() < label2.getIndex()) {
			l1 = label1;
			l2 = label2;
		} else {
			l1 = label2;
			l2 = label1;
		}
	}
			
	public Label getLabel1() {
		return l1;
	}
	
	public Label getLabel2() {
		return l2;
	}
	
	public boolean equals(Interference c2) {
		return (l1.getIndex() == c2.l1.getIndex() && l2.getIndex() == c2.l2.getIndex());
	}
	
	@Override
	public int compareTo(Interference c2) {
		if (l1.getIndex() < c2.l1.getIndex()) {
			return -1;
		} else if (l1.getIndex() > c2.l1.getIndex()) {
			return 1;
		} else {
			if (l2.getIndex() < c2.l2.getIndex()) {
				return -1;
			} else if (l2.getIndex() > c2.l2.getIndex()) {
				return 1;
			} else {
				return 0;
			}	
		}
	}
}
