package labeling;

import com.vividsolutions.jts.geom.Polygon;

/**
 * @author haunert
 * 
 * When using or adapting this code for your research, please cite:
 * 
 * Jan-Henrik Haunert and Alexander Wolff
 * Beyond Maximum Independent Set: An Extended Integer Programming Formulation for Point Labeling
 * International Journal of Geo-Information, 2017
 */
public class Label implements Comparable<Label> {
	private Polygon polygon;
	private Point point;
	private double weight;
	private String text;
	private int index;
	
	public Label(Polygon pol, Point poi, double w, int i) {
		polygon = pol;
		point = poi;
		weight = w;
		index = i;
	}
	
	public Polygon getPolygon() {
		return polygon;
	}
	
	public Point getPoint() {
		return point;
	}
	
	public double getWeight() {
		return weight;
	}
		
	public int getIndex() {
		return index;
	}

	public Point getCenter() {
		com.vividsolutions.jts.geom.Point p = polygon.getCentroid();
		return new Point(p.getX(), p.getY());
	}

	public boolean equals(Label arg0) {
		return index == arg0.index;
	}
	
	@Override
	public int compareTo(Label arg0) {
		return index - arg0.index;
	}

	public String getText() {
		return text;
	}

	public void setText(String text) {
		this.text = text;
	}
	
}
