package labeling;

import java.util.LinkedList;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.GeometryFactory;
import com.vividsolutions.jts.geom.Polygon;
import com.vividsolutions.jts.util.GeometricShapeFactory;

/**
 * @author haunert
 * 
 * When using or adapting this code for your research, please cite:
 * 
 * Jan-Henrik Haunert and Alexander Wolff
 * Beyond Maximum Independent Set: An Extended Integer Programming Formulation for Point Labeling
 * International Journal of Geo-Information, 2017
 */
public class Point {
	private double x;
	private double y;
	private LinkedList<Label> labels;	
	
	public Point(double x, double y) {
		this.x = x;
		this.y = y;
		labels = new LinkedList<Label>();
	}
	
	public void addLabel(Label l) {
		labels.add(l);
	}
	public double getX() {
		return x;
	}
	public void setX(double x) {
		this.x = x;
	}
	public double getY() {
		return y;
	}
	public void setY(double y) {
		this.y = y;
	}
	public LinkedList<Label> getLabels() {
		return labels;
	}
	
	public double getDistance(Point pj) {
		double dx = x - pj.x;
		double dy = y - pj.y;
		
		return Math.sqrt(dx * dx + dy * dy);
	}

	public Polygon getCircle(double r, int n_segs) {
		GeometricShapeFactory gsf = new GeometricShapeFactory();
		gsf.setCentre(new Coordinate(x,y));
		gsf.setNumPoints(n_segs);
		gsf.setWidth(2 * r);
		gsf.setHeight(2 * r);
		return gsf.createCircle();
		
	}

	public double getDistance(Label receiver) {
		
		return toJtsPoint().distance(receiver.getPolygon());
	}

	public com.vividsolutions.jts.geom.Point toJtsPoint() {
		GeometryFactory gf = new GeometryFactory();
		Coordinate coord = new Coordinate(x, y);
		return gf.createPoint(coord);
	}
}
