package labeling;

import java.io.IOException;
import java.io.PrintWriter;

import gurobi.GRBException;

/**
 * @author haunert
 * 
 * When using or adapting this code for your research, please cite:
 * 
 * Jan-Henrik Haunert and Alexander Wolff
 * Beyond Maximum Independent Set: An Extended Integer Programming Formulation for Point Labeling
 * International Journal of Geo-Information, 2017
 */

public class RandomInstancesMain {

    public static void main(String[] args) throws GRBException, IOException {
        
        LabelingAlgorithms.writer = new PrintWriter("summary.log", "UTF-8");
        LabelingAlgorithms.startLogging();
        
        //number of instances to be tested
        int n_instances = 10;
        
        //number of points per instance
        int n_points = 100;
        
        //width of rectangle containing all points
        double instance_width = 10.0;
        
        //width of rectangle containing all points
        double instance_height = 10.0;
        
        //width of label
        double label_width = 1.0;
        
        //height of label
        double label_height = 0.5;

        LabelingAlgorithms.epsilon = 0.01;
        LabelingAlgorithms.lambda = 0.02;
        LabelingAlgorithms.alpha = 0.4;
        LabelingAlgorithms.gamma_width = 2.0;
        LabelingAlgorithms.k_gamma = 2;
        LabelingAlgorithms.scale = 1.0;
                
        for (int i = 0; i < n_instances; i++) {
            LabelingAlgorithms.solveRandomInstance(i, true, instance_width, instance_height, n_points, label_height, label_width);
        }
                
        LabelingAlgorithms.writeSummaryStatistics();
        
        LabelingAlgorithms.writer.flush();
        LabelingAlgorithms.writer.close();
    }
}
