package rectangleSweep;

/**
 * @author haunert
 * 
 * When using or adapting this code for your research, please cite:
 * 
 * Jan-Henrik Haunert and Alexander Wolff
 * Beyond Maximum Independent Set: An Extended Integer Programming Formulation for Point Labeling
 * International Journal of Geo-Information, 2017
 */
public class Event<E> implements Comparable<Event<E>> {
   private boolean isBegin;
   private double time;
   private RectangleWithInfo<E> r;
   
   public Event(RectangleWithInfo<E> r, boolean isBegin, double time) {
      this.isBegin = isBegin;
      this.time = time;
      this.r = r;
   }
   
   
   @Override
   public int compareTo(Event<E> o) {
      if (time == o.time) {
         if (isBegin && !o.isBegin) {
            return -1;
         } else if (!isBegin && o.isBegin) {
            return 1;
         } else {
            return r.compareTo(o.r);
         }
      } 
      return (int) Math.signum(time - o.time);
   }
   
   public double getTime() {
      return time;
   }


   public boolean isBegin() {
      return isBegin;
   }


   public RectangleWithInfo<E> getR() {
      return r;
   }
   
   public String toString() {
      return isBegin + " " + r.toString();
   }


   public String toShortString() {
      return "(" + isBegin + ": " + r.getName() + ") ";
   }
}
