package rectangleSweep;

import com.vividsolutions.jts.geom.CoordinateSequence;
import com.vividsolutions.jts.geom.GeometryFactory;
import com.vividsolutions.jts.geom.LinearRing;
import com.vividsolutions.jts.geom.Polygon;
import com.vividsolutions.jts.geom.impl.CoordinateArraySequence;

/**
 * @author haunert
 * 
 * When using or adapting this code for your research, please cite:
 * 
 * Jan-Henrik Haunert and Alexander Wolff
 * Beyond Maximum Independent Set: An Extended Integer Programming Formulation for Point Labeling
 * International Journal of Geo-Information, 2017
 */
public class Rectangle implements Comparable<Rectangle> {
   
   private double xMin;
   private double yMin;
   private double width;
   private double height;
   private String name;
   
   public Rectangle(double xMin, double yMin, double width, double height, String name) {
      this.xMin = xMin;
      this.yMin = yMin;
      this.width = width;
      this.height = height;
      this.name = name;
   }
   
   public void setHeight(double height) {
      this.height = height;
   }
   
   public double getHeight() {
      return height;
   }

   public double getxMin() {
      return xMin;
   }

   public double getyMin() {
      return yMin;
   }

   public double getWidth() {
      return width;
   }

   @Override
   public int compareTo(Rectangle r2) {
      if (yMin < r2.yMin) return -1;
      if (yMin > r2.yMin) return 1;
      return (int) Math.signum(xMin - r2.xMin);
   }
   
   public String toString() {
      return name + ": (" + xMin + " " + yMin + ") (" + (xMin + width) + " " + (yMin + height) + ")";
   }

   public String getName() {
      return name;
   }
   
   public Polygon getAsPolygon() {
    GeometryFactory gf = new GeometryFactory();   
      
    CoordinateSequence myseq = new CoordinateArraySequence(5);
    
    myseq.setOrdinate(0, 0, xMin);
    myseq.setOrdinate(0, 1, yMin);
    
    myseq.setOrdinate(1, 0, xMin);
    myseq.setOrdinate(1, 1, yMin + height);
    
    myseq.setOrdinate(2, 0, xMin + width);
    myseq.setOrdinate(2, 1, yMin + height);
    
    myseq.setOrdinate(3, 0, xMin + width);
    myseq.setOrdinate(3, 1, yMin);
    
    myseq.setOrdinate(4, 0, xMin);
    myseq.setOrdinate(4, 1, yMin);
    
    LinearRing myRing = new LinearRing(myseq , gf);
    return new Polygon(myRing, null, gf);
       
   }
}
